==> pochy-0.1.4a-src.tar.gz: pochy-0.1.4a-src/MultiPartView.h <==
#if !defined(AFX_MULTIPARTVIEW_H__CC7E6E8C_D4B2_45B4_AE1A_08DD7407D88A__INCLUDED_)
#define AFX_MULTIPARTVIEW_H__CC7E6E8C_D4B2_45B4_AE1A_08DD7407D88A__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// MultiPartView.h : wb_[ t@C
//

/////////////////////////////////////////////////////////////////////////////
// CMultiPartView r[

class CMultiPartView : public CListView
{
protected:
	CMultiPartView();           // IɎgpveNg RXgN^
	DECLARE_DYNCREATE(CMultiPartView)

// Agr[g
public:
	int m_index;

// Iy[V
public:
	void ExecuteFile();
	void ReArrange();

//protected:
	CImageList m_image;
// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B

	//{{AFX_VIRTUAL(CMultiPartView)
	public:
	virtual void OnInitialUpdate();
	protected:
	virtual void OnDraw(CDC* pDC);      // ̃r[`悷邽߂ɃI[o[Ch܂B
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	//}}AFX_VIRTUAL

// Cve[V
protected:
	virtual ~CMultiPartView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

	// ꂽbZ[W }bv֐
protected:
	//{{AFX_MSG(CMultiPartView)
	afx_msg void OnItemchanged(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnRclick(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnChar(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnDblclk(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnMultipartSave2file();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MULTIPARTVIEW_H__CC7E6E8C_D4B2_45B4_AE1A_08DD7407D88A__INCLUDED_)

==> pochy-0.1.9-src.tar.gz: pochy-0.1.9-src/MultiPartView.h <==
#if !defined(AFX_MULTIPARTVIEW_H__CC7E6E8C_D4B2_45B4_AE1A_08DD7407D88A__INCLUDED_)
#define AFX_MULTIPARTVIEW_H__CC7E6E8C_D4B2_45B4_AE1A_08DD7407D88A__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// MultiPartView.h : wb_[ t@C
//
// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
#include "BitmapListView.h"
// end

/////////////////////////////////////////////////////////////////////////////
// CMultiPartView r[

// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
//class CMultiPartView : public CListView
class CMultiPartView : public CBitmapListView
// end
{
protected:
	CMultiPartView();           // IɎgpveNg RXgN^
	DECLARE_DYNCREATE(CMultiPartView)

// Agr[g
public:
	int m_index;

// Iy[V
public:
	void ExecuteFile();
	void ReArrange();

//protected:
	CImageList m_image;
// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B

	//{{AFX_VIRTUAL(CMultiPartView)
	public:
	virtual void OnInitialUpdate();
	protected:
	virtual void OnDraw(CDC* pDC);      // ̃r[`悷邽߂ɃI[o[Ch܂B
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	//}}AFX_VIRTUAL

// Cve[V
protected:
	virtual ~CMultiPartView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

	// ꂽbZ[W }bv֐
protected:
	//{{AFX_MSG(CMultiPartView)
	afx_msg void OnItemchanged(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnRclick(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnChar(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnDblclk(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnMultipartSave2file();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MULTIPARTVIEW_H__CC7E6E8C_D4B2_45B4_AE1A_08DD7407D88A__INCLUDED_)
